@@ -26,7 +26,7 @@
 
 #include "s3m.h"
 
-const char
+const signed char
   Cs3mPlayer::chnresolv[] =     // S3M -> adlib channel conversion
 { -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 0, 1, 2, 3,
     4, 5, 6, 7, 8, -1, -1, -1, -1, -1, -1, -1 };
