@@ -21,16 +21,6 @@
 #ifndef _I_CONFIGURE_FLUIDSYNTH_H
 #define _I_CONFIGURE_FLUIDSYNTH_H 1
 
-#include <gtk/gtk.h>
-
-#ifdef AMIDIPLUG_FLUIDSYNTH
-
-void i_configure_gui_tab_fsyn (GtkWidget *, void *, void *);
-void i_configure_gui_tablabel_fsyn (GtkWidget *, void *, void *);
-void i_configure_cfg_fsyn_free (void);
-void i_configure_cfg_fsyn_read (void);
-void i_configure_cfg_fsyn_save (void);
-
-#endif /* AMIDIPLUG_FLUIDSYNTH */
+void * create_soundfont_list (void);
 
 #endif /* !_I_CONFIGURE_FLUIDSYNTH_H */
