@@ -23,12 +23,13 @@
 GtkWidget * playlist_get_treeview (int playlist);
 
 int playlist_count_selected_in_range (int list, int top, int length);
-void playlist_song_info (void);
-void playlist_queue_toggle (void);
-void playlist_delete_selected (void);
-void playlist_copy (void);
-void playlist_cut (void);
-void playlist_paste (void);
+void playlist_song_info ();
+void playlist_open_folder ();
+void playlist_queue_toggle ();
+void playlist_delete_selected ();
+void playlist_copy ();
+void playlist_cut ();
+void playlist_paste ();
 void playlist_shift (int offset);
 
 #endif
