@@ -56,18 +56,26 @@ void action_playlist_reverse_list(void);
 void action_playlist_sort_by_title(void);
 void action_playlist_sort_by_album(void);
 void action_playlist_sort_by_artist(void);
+void action_playlist_sort_by_album_artist(void);
+void action_playlist_sort_by_length(void);
+void action_playlist_sort_by_genre(void);
 void action_playlist_sort_by_filename(void);
 void action_playlist_sort_by_full_path(void);
 void action_playlist_sort_by_date(void);
 void action_playlist_sort_by_track_number(void);
+void action_playlist_sort_by_custom_title(void);
 
 void action_playlist_sort_selected_by_title(void);
 void action_playlist_sort_selected_by_album(void);
 void action_playlist_sort_selected_by_artist(void);
+void action_playlist_sort_selected_by_album_artist(void);
+void action_playlist_sort_selected_by_length(void);
+void action_playlist_sort_selected_by_genre(void);
 void action_playlist_sort_selected_by_filename(void);
 void action_playlist_sort_selected_by_full_path(void);
 void action_playlist_sort_selected_by_date(void);
 void action_playlist_sort_selected_by_track_number(void);
+void action_playlist_sort_selected_by_custom_title(void);
 
 void action_playlist_track_info(void);
 void action_queue_toggle(void);
