@@ -27,17 +27,24 @@
 static void widget_realized (GtkWidget * w)
 {
     GdkWindow * window = gtk_widget_get_window (w);
-    gdk_window_set_background_pattern (window, NULL);
+    gdk_window_set_back_pixmap (window, nullptr, FALSE);
 }
 
-#define DRAW_SIGNAL "draw"
-#define DRAW_FUNC_BEGIN(n) static gboolean n (GtkWidget * wid, cairo_t * cr) { \
- g_return_val_if_fail (wid && cr, FALSE);
-#define DRAW_FUNC_END return FALSE; }
+#define DRAW_SIGNAL "expose-event"
+#define DRAW_FUNC_BEGIN(n) static int n (GtkWidget * wid, GdkEventExpose * ev) { \
+ cairo_t * cr = gdk_cairo_create (gtk_widget_get_window (wid));
+#define DRAW_FUNC_END cairo_destroy (cr); \
+ return TRUE; }
+
+/* We set None as the background pixmap in order to avoid flickering.  Setting
+ * a blank GtkStyle prevents GTK 2.x from overriding this. */
 
 #define DRAW_CONNECT(w,f) do { \
-    g_signal_connect (w, "realize", (GCallback) widget_realized, NULL); \
-    g_signal_connect (w, DRAW_SIGNAL, (GCallback) f, NULL); \
+    GtkStyle * style = gtk_style_new (); \
+    gtk_widget_set_style (w, style); \
+    g_object_unref (style); \
+    g_signal_connect (w, "realize", (GCallback) widget_realized, nullptr); \
+    g_signal_connect (w, DRAW_SIGNAL, (GCallback) f, nullptr); \
  } while (0);
 
 #endif
